@@ -36,6 +36,8 @@ class JsonEncoder(json.JSONEncoder):
             return obj.value
         elif isinstance(obj, ConfirmNeeded):
             return obj.__dict__
+        elif isinstance(obj, ConfirmTask):
+            return obj.__dict__
         else:
             return json.JSONEncoder.default(self, obj)
 
@@ -76,6 +78,8 @@ class JsonDecoder(json.JSONDecoder):
                 return CompleteTask(**obj)
             if '_type' in obj and obj['_type'] == 'confirm_needed':
                 return ConfirmNeeded(**obj)
+            if '_type' in obj and obj['_type'] == 'confirm_task':
+                return ConfirmTask(**obj)
         return obj
 
 
