@@ -5,4 +5,4 @@ from holour.msg.script import Script, WaypointConfig
 from holour.msg.task import Task
 from holour.msg.product import Product
 from holour.msg.process import Process
-from holour.msg.assembly import AddProcess, MoveTask, CompleteTask, Destination, ConfirmNeeded
+from holour.msg.assembly import AddProcess, MoveTask, CompleteTask, Destination, ConfirmNeeded, ConfirmTask
