@@ -26,3 +26,9 @@ class Test(TestCase):
         assert s1 == s2
         assert s1 != s3
         assert s1 != "not status"
+
+    def test_status_repr(self):
+        status = Status('data_objects', '127.0.0.1', Status.OFFLINE)
+        expected, got = '127.0.0.1', f'{status}'
+
+        assert expected in got, f"Expected {expected} in got: {got}"
